python ..\pageCatcher.pyc exec example1_fillform.py
python ..\pageCatcher.pyc exec example2_reverse.py
python ..\pageCatcher.pyc exec example3_append.py
python ..\pageCatcher.pyc exec example4_fourpage.py
python ..\pageCatcher.pyc exec example5_background.py
python ..\pageCatcher.pyc exec example6_twopage.py
python ..\pageCatcher.pyc exec example7_split.py
