<!--DOCTYPE HTML PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"-->
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
<meta content="text/html; charset=UTF-8" http-equiv="Content-Type"/>
<title>Reportlab Travel Plan Demo</title>
<meta content="true" name="MSSmartTagsPreventParsing"/>
<link href="/rsrc/travelplan/dsmain.css" type="text/css" rel="stylesheet"/>
<link href="/rsrc/travelplan/common.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="/rsrc/travelplan/date.js"></script>
<!--javascriptsnip--><!--javascriptsnip-->
</head>
<body onload="<!--onloadsnip--><!--onloadsnip-->">
	<div id="content">
					<div id="header">
							<h2><img src="/rsrc/travelplan/rptlablogo.gif" width="70" align="left" alt="reportlab logo"/>&nbsp;&nbsp;&nbsp;Reportlab Travelplan Demo</h2>
					</div>
  <!--user content starts here-->, 
            <p>this will be replaced</p>
    <!--user content ends here-->
		<div id="footer">
			<div>
				<div>
					<table width="100%" style="font-size:97%">
						<tr>
							<td align="left">	Reportlab Europe Ltd
							</td>
							<td align="right">	Copyright (C) 2000-2006; All rights reserved.
							</td>
						</tr>
					</table>
				</div>
			</div>
		</div>
	</div>
</body>
</html>
